@@ -166,6 +166,8 @@ cleanup () { # Undo all changes
 	set +e
 	trap - EXIT
 
+	kill_proxy
+
 	[ -f "${BASEDIR}/reenable_mirror" ] && a2ensite univention-repository >&3 2>&3
 	find -P /etc/apache2 -lname "${BASEDIR}/*" -delete
 	[ "$apache_mod_groupfile_enabled" -eq 0 ] ||
@@ -269,6 +271,16 @@ setup_apache () { # Setup apache for repository: [--port ${port}] [${prefix}]
 	apache2ctl restart >&3 2>&3
 }
 
+config_proxy () { # Run HTTP proxy: ...
+	kill_proxy
+	eval "$(python3 proxy.py -f -p 0 "$@" 3>&-)"
+}
+kill_proxy () { # Kill HTTP proxy
+	[ -n "${proxy_pid:-}" ] || return 0
+	kill "${proxy_pid:?}" 2>&3
+	unset proxy_pid
+}
+
 config_repo () { # Configure use of repository from local apache: [[server]:port] [/prefix] [urcv=value]...
 	local server=localhost
 	local port=80
@@ -446,8 +458,7 @@ mkpdir () { # Create package directory ${dir}
 				DIR="${REPODIR}/${version%%-*}/${part}/${version#*--}/${arch}"
 				DIRS+=("${DIR}")
 				mkdir -p "${DIR}"
-				touch "${DIR}/Packages"
-				compress "${DIR}/Packages"
+				mkpkg "${DIR}" "${DIR}"
 			done
 		done
 	done
